@@ -18,6 +18,7 @@ gaWrapper<-function(gaArgs=NULL,        # can specify your own outside
                     attInfo=NULL,       # added info regarding attributes
                     datInd=NULL,
                     randomVector = NULL,
+                    randomUnitNormalVector = NULL,
                     parSuggest=NULL,    # paramater suggestions
                     target=NULL,        # target locations: desired changes in climate to be simulated, in % relative or abs diff to baseline levels (vector)
                     attObs=NULL,        # observed series attribute values
@@ -53,6 +54,7 @@ gaWrapper<-function(gaArgs=NULL,        # can specify your own outside
               attInfo=attInfo, 
               datInd=datInd,
               randomVector = randomVector,
+              randomUnitNormalVector = randomUnitNormalVector,
               target=target,        
               attObs=attObs,        
               lambda.mult=lambda.mult,   
